﻿/**
 * @license Copyright (c) 2003-2017, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

/**
 * This file was added automatically by CKEditor builder.
 * You may re-use it at any time to build CKEditor again.
 *
 * If you would like to build CKEditor online again
 * (for example to upgrade), visit one the following links:
 *
 * (1) http://ckeditor.com/builder
 *     Visit online builder to build CKEditor from scratch.
 *
 * (2) http://ckeditor.com/builder/efd88158c12886c4be7d99e4915df4d6
 *     Visit online builder to build CKEditor, starting with the same setup as before.
 *
 * (3) http://ckeditor.com/builder/download/efd88158c12886c4be7d99e4915df4d6
 *     Straight download link to the latest version of CKEditor (Optimized) with the same setup as before.
 *
 * NOTE:
 *    This file is not used by CKEditor, you may remove it.
 *    Changing this file will not change your CKEditor configuration.
 */

var CKBUILDER_CONFIG = {
	skin: 'minimalist',
	preset: 'basic',
	ignore: [
		'.bender',
		'bender.js',
		'bender-err.log',
		'bender-out.log',
		'dev',
		'.DS_Store',
		'.editorconfig',
		'.gitattributes',
		'.gitignore',
		'gruntfile.js',
		'.idea',
		'.jscsrc',
		'.jshintignore',
		'.jshintrc',
		'less',
		'.mailmap',
		'node_modules',
		'package.json',
		'README.md',
		'tests'
	],
	plugins : {
		'about' : 1,
		'base64image' : 1,
		'basicstyles' : 1,
		'blockquote' : 1,
		'button' : 1,
		'clipboard' : 1,
		'colorbutton' : 1,
		'colordialog' : 1,
		'contextmenu' : 1,
		'dialog' : 1,
		'dialogui' : 1,
		'div' : 1,
		'enterkey' : 1,
		'entities' : 1,
		'fakeobjects' : 1,
		'floatingspace' : 1,
		'floatpanel' : 1,
		'font' : 1,
		'format' : 1,
		'image' : 1,
		'indentlist' : 1,
		'justify' : 1,
		'link' : 1,
		'list' : 1,
		'listblock' : 1,
		'menu' : 1,
		'menubutton' : 1,
		'onchange' : 1,
		'panel' : 1,
		'panelbutton' : 1,
		'pastefromexcel' : 1,
		'pastefromword' : 1,
		'pastetext' : 1,
		'richcombo' : 1,
		'scayt' : 1,
		'sourcearea' : 1,
		'tab' : 1,
		'table' : 1,
		'tableresize' : 1,
		'tabletools' : 1,
		'toolbar' : 1,
		'undo' : 1,
		'wsc' : 1,
		'wysiwygarea' : 1
	},
	languages : {
		'ar' : 1,
		'ca' : 1,
		'cs' : 1,
		'cy' : 1,
		'da' : 1,
		'de' : 1,
		'en' : 1,
		'es' : 1,
		'eu' : 1,
		'fi' : 1,
		'fr' : 1,
		'hr' : 1,
		'hu' : 1,
		'is' : 1,
		'it' : 1,
		'lt' : 1,
		'mk' : 1,
		'nb' : 1,
		'nl' : 1,
		'no' : 1,
		'pl' : 1,
		'pt' : 1,
		'pt-br' : 1,
		'ru' : 1,
		'sk' : 1,
		'sl' : 1,
		'sr' : 1,
		'sv' : 1,
		'tr' : 1,
		'uk' : 1,
		'zh' : 1,
		'zh-cn' : 1
	}
};